package com.ruoyi.ems.mapper;

import java.util.List;
import com.ruoyi.ems.domain.AdmOpAlarmPolicy;

/**
 * 能源设施告警策略Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-26
 */
public interface AdmOpAlarmPolicyMapper 
{
    /**
     * 查询能源设施告警策略
     * 
     * @param id 能源设施告警策略主键
     * @return 能源设施告警策略
     */
    public AdmOpAlarmPolicy selectAdmOpAlarmPolicyById(Long id);

    /**
     * 查询能源设施告警策略列表
     * 
     * @param admOpAlarmPolicy 能源设施告警策略
     * @return 能源设施告警策略集合
     */
    public List<AdmOpAlarmPolicy> selectAdmOpAlarmPolicyList(AdmOpAlarmPolicy admOpAlarmPolicy);

    /**
     * 新增能源设施告警策略
     * 
     * @param admOpAlarmPolicy 能源设施告警策略
     * @return 结果
     */
    public int insertAdmOpAlarmPolicy(AdmOpAlarmPolicy admOpAlarmPolicy);

    /**
     * 修改能源设施告警策略
     * 
     * @param admOpAlarmPolicy 能源设施告警策略
     * @return 结果
     */
    public int updateAdmOpAlarmPolicy(AdmOpAlarmPolicy admOpAlarmPolicy);

    /**
     * 删除能源设施告警策略
     * 
     * @param id 能源设施告警策略主键
     * @return 结果
     */
    public int deleteAdmOpAlarmPolicyById(Long id);

    /**
     * 批量删除能源设施告警策略
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAdmOpAlarmPolicyByIds(Long[] ids);
}
